@@ -1,7 +1,5 @@
-# #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # <HTTPretty - HTTP client mock for Python>
-# Copyright (C) <2011-2015>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2011-2020> Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -23,26 +21,17 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 # OTHER DEALINGS IN THE SOFTWARE.
-from __future__ import unicode_literals
-
-from .compat import (
-    byte_type, text_type
-)
 
 
 def utf8(s):
-    if isinstance(s, text_type):
+    if isinstance(s, str):
         s = s.encode('utf-8')
-    elif s is None:
-        return byte_type()
 
-    return byte_type(s)
+    return bytes(s)
 
 
 def decode_utf8(s):
-    if isinstance(s, byte_type):
+    if isinstance(s, bytes):
         s = s.decode("utf-8")
-    elif s is None:
-        return text_type()
 
-    return text_type(s)
+    return str(s)
